#
# spec file for package homeshick
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           homeshick
Version:        2.0.1
Release:        1.4
Summary:        Dotfile synchronizer based on Git and Bash
License:        MIT
Group:          Productivity/File utilities
URL:            https://github.com/andsens/homeshick
Source0:        https://github.com/andsens/homeshick/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        README-openSUSE.md
Source50:       https://github.com/bats-core/bats-file/archive/v0.3.0.tar.gz#/bats-file-0.3.0.tar.gz
Source51:       https://github.com/bats-core/bats-support/archive/v0.3.0.tar.gz#/bats-support-0.3.0.tar.gz
Source52:       https://github.com/bats-core/bats-assert/archive/v2.0.0.tar.gz#/bats-assert-2.0.0.tar.gz
Source99:       homeshick.rpmlintrc
Patch0:         suse-packaging.patch
Patch1:         test-helper.patch
BuildRequires:  expect
BuildRequires:  git >= 1.5
BuildRequires:  iputils
BuildRequires:  tcsh
Requires:       bash >= 3
Requires:       git >= 1.5
BuildArch:      noarch
%if 0%{?is_opensuse}
BuildRequires:  bats
BuildRequires:  dash
BuildRequires:  fish
%endif

%description
Homeshick is a tool for users to manage configuration files, also known as
dotfiles. It leverages Git repositories to store and version dotfiles, and to
synchronize dotfile repositories between accounts and/or machines.

For example, this allows managing personal dotfiles alongside emacs or vim
plugins without clutter. It also makes it easy to install large external
frameworks, such as oh-my-zsh, found on sites like https://dotfiles.github.io/.

%prep
%autosetup -p1

# unpack test libraries
mkdir -p test/bats/lib
for lib in file support assert; do
	tar -xf %{_sourcedir}/bats-$lib-*.tar.gz -C test/bats/lib --transform "s/bats-$lib-...../$lib/"
done

%build

%install
mkdir -p %{buildroot}%{_datadir}/%{name}
mv %{name}.sh %{name}.fish %{name}.csh bin lib completions %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_bindir}
ln -s %{_datadir}/%{name}/bin/homeshick %{buildroot}%{_bindir}/%{name}
cp %{SOURCE1} .

%check
# run tests if bats is available
if type bats &>/dev/null; then
	HOMESHICK_DIR=%{buildroot}%{_datadir}/%{name} HOMESHICK_TEST_DIR="$PWD" bats test/suites
fi

%files
%doc README.md README-openSUSE.md CONTRIBUTING.md
%license LICENSE
%{_datadir}/%{name}
%{_bindir}/homeshick

%changelog
* Tue May 16 2023 Jan Engelhardt <jengelh@inai.de>
- Use autosetup and POSIX tar options.
* Sat May 13 2023 Olav Reinert <seroton10@gmail.com>
- Upgrade to version 2.0.1:
  * Improvements to testing (@oreinert)
  * Test up to and including bash v5.2.9
  * Improvements to cd and check subcommands (@me-and)
  * Improvement to cd subcommand in fish (@languitar)
- Remove patch git-config-for-tests.patch:
  * Included by upstream
- Add patch test-helper.patch:
  * Allows tests to run on OBS; does not alter package contents
* Wed Nov 16 2022 Olav Reinert <seroton10@gmail.com>
- Improve fix for build issue against Factory:
  * Replace git-protocol-file-allow.patch with git-config-for-tests.patch
* Fri Nov 11 2022 Olav Reinert <seroton10@gmail.com>
- Fix build issue against Factory:
  * Add patch git-protocol-file-allow.patch
* Sat May 16 2020 Olav Reinert <seroton10@gmail.com>
- Upgrade to version 2.0.0:
  * Breaking: Moved ./bin/homeshick.csh to ./homeshick.csh
  * Speed up refresh operation by reducing exec calls
  * Fix some path quoting issues
* Thu Jun  7 2018 seroton10@gmail.com
- Upgrade to version 1.1.0:
  * symlinks are now relative (useful when linking for a chrooted environment
    or when renaming the home folder)
  * fish shell completion (guide in wiki)
  * homeshick.sh can now be sourced from dash as well
  * the entire codebase is now linted with shellcheck
  * loads of minor bugfixes
- Rename default-location.patch to suse-packaging.patch
* Tue May 26 2015 seroton10@gmail.com
- Upstream introduced version numbers; no change of content.
* Sun Apr 26 2015 seroton10@gmail.com
- Added README for openSUSE.
* Fri Apr 24 2015 seroton10@gmail.com
- Make homeshick command available by default
* Sun Apr 19 2015 seroton10@gmail.com
- PRs #135 and #138 accepted upstream, which allows running BATS
  tests in %%check section without patches.
* Mon Apr 13 2015 seroton10@gmail.com
- Latest obs_compat fixes, spec-cleaning.
* Sat Apr 11 2015 seroton10@gmail.com
- First build with running BATS tests
  * Based on development branch for required fix
* Sun Nov  9 2014 seroton10@gmail.com
- Initial version
